@@ -10,7 +10,7 @@ import shutil
 import pickle
 import os
 import gzip
-from cepy.utils import normalize
+from cepy.utils import normalize, check_adjacency_matrix
 import warnings
 
 class CE:
@@ -49,6 +49,8 @@ class CE:
         Ignores all nodes with total frequency lower than this.
     iter : int, optional
         Number of iterations (epochs) over all random walk samples.
+    save_walks: bool, optional
+        Whether  to save the sampled random walks, if True will result in larger memory consumption.
     word2vec_kws : dict, optional
         Additional parameteres for gensim.models.Word2Vec. Notice that window, min_count,
         iter should be entered as separate parameters (would be ignored).
@@ -78,14 +80,14 @@ class CE:
     >>> # Extract the same cosine similarity again, this should be identical apart from minor numerical difference
     >>> ce_loaded_copy.similarity()[0, 1]
     0.6134564518636314
-
     """
 
     def __init__(self, dimensions: int = 30, walk_length: int = 20, num_walks: int = 800,
                  permutations: int = 100, p: float = 1, q: float = 1,
                  weight_key: str = 'weight', workers: int = 1, sampling_strategy: dict = None,
                  verbosity: int = 1, temp_folder: str = None, seed: int = None, window: int = 3,
-                 min_count: int = 0, iter: int = 1, word2vec_kws: dict = {}):
+                 min_count: int = 0, iter: int = 1, save_walks:bool = False,
+                 word2vec_kws: dict = {}):
 
         """
         Initiates the connectome embedding object.
@@ -103,6 +105,8 @@ class CE:
 
         self.dimensions = dimensions
         self.walk_length = walk_length
+        if num_walks < 800:
+            warnings.warn('num_walks is recommended to be at least 800, but is ' + str(num_walks) + '.')
         self.num_walks = num_walks
         self.p = p
         self.q = q
@@ -112,7 +116,7 @@ class CE:
         self.d_graph = defaultdict(dict)
         self.word2vec_kws = word2vec_kws
         self.permutations = permutations
-
+        self.save_walks = save_walks
         if sampling_strategy is None:
             self.sampling_strategy = {}
         else:
@@ -150,7 +154,7 @@ class CE:
 
         d_graph = self.d_graph
 
-        nodes_generator = self.graph.nodes() if self.verbosity > 1 \
+        nodes_generator = self.graph.nodes() if self.verbosity <= 1 \
             else tqdm(self.graph.nodes(), desc='Computing transition probabilities')
 
         for source in nodes_generator:
@@ -282,17 +286,15 @@ class CE:
         
         Returns
         ----------
-        ce_model: CE
-            Fitted connectome embedding object
 
+        walks: list, optional
+            List of lists of nodes
         '''
 
-        assert type(X) == np.ndarray, ('Input is expected as a numpy array')
-        assert np.all(X >= 0), ('No negative edges allowed in the adjacency matrix')
-        assert np.all(X == X.T), ('The adjacency matrix is expected to be symmetric')
+        check_adjacency_matrix(X)
         self.X = X
 
-        # deal with zero-connected components
+        # deal with zero-connected nodes
         self.nonzero_indices = np.where(self.X.sum(axis=0) > 0)[0]
         nonzero_adjacency_mat = self.X[self.nonzero_indices, :][:, self.nonzero_indices]
 
@@ -307,7 +309,10 @@ class CE:
         self._learn_embeddings()
 
         shutil.rmtree(os.path.dirname(self.temp_walks_path))
-        del self.walks
+
+        if not self.save_walks:
+            del self.walks
+
 
     class Weights:
         '''
